@@ -24,13 +24,14 @@
 
 #include <string.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <glib/gstdio.h>
 
 #include "empathy-log-manager.h"
-#include "gossip-contact.h"
-#include "gossip-time.h"
-#include "gossip-debug.h"
-#include "gossip-utils.h"
+#include "empathy-contact.h"
+#include "empathy-time.h"
+#include "empathy-debug.h"
+#include "empathy-utils.h"
 
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
 		       EMPATHY_TYPE_LOG_MANAGER, EmpathyLogManagerPriv))
@@ -45,7 +46,7 @@
 #define LOG_TIME_FORMAT           "%Y%m%d"
 #define LOG_HEADER \
     "<?xml version='1.0' encoding='utf-8'?>\n" \
-    "<?xml-stylesheet type=\"text/xsl\" href=\"gossip-log.xsl\"?>\n" \
+    "<?xml-stylesheet type=\"text/xsl\" href=\"empathy-log.xsl\"?>\n" \
     "<log>\n"
 
 #define LOG_FOOTER \
@@ -78,9 +79,10 @@ static gchar *              log_manager_get_filename_for_date      (EmpathyLogMa
 								    gboolean                chatroom,
 								    const gchar            *date);
 static gchar *              log_manager_get_timestamp_filename     (void);
-static gchar *              log_manager_get_timestamp_from_message (GossipMessage          *message);
+static gchar *              log_manager_get_timestamp_from_message (EmpathyMessage          *message);
 static EmpathyLogSearchHit *log_manager_search_hit_new             (EmpathyLogManager      *manager,
 								    const gchar            *filename);
+static void                 log_manager_search_hit_free            (EmpathyLogSearchHit    *hit);
 
 G_DEFINE_TYPE (EmpathyLogManager, empathy_log_manager, G_TYPE_OBJECT);
 
@@ -128,11 +130,11 @@ void
 empathy_log_manager_add_message (EmpathyLogManager *manager,
 				 const gchar       *chat_id,
 				 gboolean           chatroom,
-				 GossipMessage     *message)
+				 EmpathyMessage     *message)
 {
 	FILE          *file;
 	McAccount     *account;
-	GossipContact *sender;
+	EmpathyContact *sender;
 	const gchar   *body_str;
 	const gchar   *str;
 	gchar         *filename;
@@ -141,14 +143,16 @@ empathy_log_manager_add_message (EmpathyLogManager *manager,
 	gchar         *timestamp;
 	gchar         *contact_name;
 	gchar         *contact_id;
+	EmpathyMessageType msg_type;
 
 	g_return_if_fail (EMPATHY_IS_LOG_MANAGER (manager));
 	g_return_if_fail (chat_id != NULL);
-	g_return_if_fail (GOSSIP_IS_MESSAGE (message));
+	g_return_if_fail (EMPATHY_IS_MESSAGE (message));
 
-	sender = gossip_message_get_sender (message);
-	account = gossip_contact_get_account (sender);
-	body_str = gossip_message_get_body (message);
+	sender = empathy_message_get_sender (message);
+	account = empathy_contact_get_account (sender);
+	body_str = empathy_message_get_body (message);
+	msg_type = empathy_message_get_type (message);
 
 	if (G_STR_EMPTY (body_str)) {
 		return;
@@ -157,13 +161,13 @@ empathy_log_manager_add_message (EmpathyLogManager *manager,
 	filename = log_manager_get_filename (manager, account, chat_id, chatroom);
 	basedir = g_path_get_dirname (filename);
 	if (!g_file_test (basedir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
-		gossip_debug (DEBUG_DOMAIN, "Creating directory:'%s'", basedir);
+		empathy_debug (DEBUG_DOMAIN, "Creating directory:'%s'", basedir);
 
 		g_mkdir_with_parents (basedir, LOG_DIR_CREATE_MODE);
 	}
 	g_free (basedir);
 
-	gossip_debug (DEBUG_DOMAIN, "Adding message: '%s' to file: '%s'",
+	empathy_debug (DEBUG_DOMAIN, "Adding message: '%s' to file: '%s'",
 		      body_str, filename);
 
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
@@ -182,18 +186,19 @@ empathy_log_manager_add_message (EmpathyLogManager *manager,
 	body = g_markup_escape_text (body_str, -1);
 	timestamp = log_manager_get_timestamp_from_message (message);
 
-	str = gossip_contact_get_name (sender);
+	str = empathy_contact_get_name (sender);
 	contact_name = g_markup_escape_text (str, -1);
 
-	str = gossip_contact_get_id (sender);
+	str = empathy_contact_get_id (sender);
 	contact_id = g_markup_escape_text (str, -1);
 
 	g_fprintf (file,
-		   "<message time='%s' id='%s' name='%s' isuser='%s'>%s</message>\n" LOG_FOOTER,
+		   "<message time='%s' id='%s' name='%s' isuser='%s' type='%s'>%s</message>\n" LOG_FOOTER,
 		   timestamp,
 		   contact_id,
 		   contact_name,
-		   gossip_contact_is_user (sender) ? "true" : "false",
+		   empathy_contact_is_user (sender) ? "true" : "false",
+		   empathy_message_type_to_str (msg_type),
 		   body);
 
 	fclose (file);
@@ -240,12 +245,12 @@ empathy_log_manager_get_dates (EmpathyLogManager *manager,
 	directory = log_manager_get_dir (manager, account, chat_id, chatroom);
 	dir = g_dir_open (directory, 0, NULL);
 	if (!dir) {
-		gossip_debug (DEBUG_DOMAIN, "Could not open directory:'%s'", directory);
+		empathy_debug (DEBUG_DOMAIN, "Could not open directory:'%s'", directory);
 		g_free (directory);
 		return NULL;
 	}
 
-	gossip_debug (DEBUG_DOMAIN, "Collating a list of dates in:'%s'", directory);
+	empathy_debug (DEBUG_DOMAIN, "Collating a list of dates in:'%s'", directory);
 
 	while ((filename = g_dir_read_name (dir)) != NULL) {
 		if (!g_str_has_suffix (filename, LOG_FILENAME_SUFFIX)) {
@@ -264,39 +269,38 @@ empathy_log_manager_get_dates (EmpathyLogManager *manager,
 	g_free (directory);
 	g_dir_close (dir);
 
-	gossip_debug (DEBUG_DOMAIN, "Parsed %d dates", g_list_length (dates));
+	empathy_debug (DEBUG_DOMAIN, "Parsed %d dates", g_list_length (dates));
 
 	return dates;
 }
 
 GList *
-empathy_log_manager_get_messages_for_date (EmpathyLogManager *manager,
-					   McAccount         *account,
-					   const gchar       *chat_id,
-					   gboolean           chatroom,
-					   const gchar       *date)
+empathy_log_manager_get_messages_for_file (EmpathyLogManager *manager,
+					   const gchar       *filename)
 {
-	gchar            *filename;
-	GList            *messages = NULL;
-	xmlParserCtxtPtr  ctxt;
-	xmlDocPtr         doc;
-	xmlNodePtr        log_node;
-	xmlNodePtr        node;
+	GList               *messages = NULL;
+	xmlParserCtxtPtr     ctxt;
+	xmlDocPtr            doc;
+	xmlNodePtr           log_node;
+	xmlNodePtr           node;
+	EmpathyLogSearchHit *hit;
+	McAccount           *account;
 
 	g_return_val_if_fail (EMPATHY_IS_LOG_MANAGER (manager), NULL);
-	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
-	g_return_val_if_fail (chat_id != NULL, NULL);
+	g_return_val_if_fail (filename != NULL, NULL);
 
-	filename = log_manager_get_filename_for_date (manager, account, chat_id, chatroom, date);
-
-	gossip_debug (DEBUG_DOMAIN, "Attempting to parse filename:'%s'...", filename);
+	empathy_debug (DEBUG_DOMAIN, "Attempting to parse filename:'%s'...", filename);
 
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		gossip_debug (DEBUG_DOMAIN, "Filename:'%s' does not exist", filename);
-		g_free (filename);
+		empathy_debug (DEBUG_DOMAIN, "Filename:'%s' does not exist", filename);
 		return NULL;
 	}
 
+	/* Get the account from the filename */
+	hit = log_manager_search_hit_new (manager, filename);
+	account = g_object_ref (hit->account);
+	log_manager_search_hit_free (hit);
+
 	/* Create parser. */
 	ctxt = xmlNewParserCtxt ();
 
@@ -304,7 +308,6 @@ empathy_log_manager_get_messages_for_date (EmpathyLogManager *manager,
 	doc = xmlCtxtReadFile (ctxt, filename, NULL, 0);
 	if (!doc) {
 		g_warning ("Failed to parse file:'%s'", filename);
-		g_free (filename);
 		xmlFreeParserCtxt (ctxt);
 		return NULL;
 	}
@@ -312,7 +315,6 @@ empathy_log_manager_get_messages_for_date (EmpathyLogManager *manager,
 	/* The root node, presets. */
 	log_node = xmlDocGetRootElement (doc);
 	if (!log_node) {
-		g_free (filename);
 		xmlFreeDoc (doc);
 		xmlFreeParserCtxt (ctxt);
 		return NULL;
@@ -320,15 +322,17 @@ empathy_log_manager_get_messages_for_date (EmpathyLogManager *manager,
 
 	/* Now get the messages. */
 	for (node = log_node->children; node; node = node->next) {
-		GossipMessage *message;
-		GossipContact *sender;
-		gchar         *time;
-		GossipTime     t;
-		gchar         *sender_id;
-		gchar         *sender_name;
-		gchar         *body;
-		gchar         *is_user_str;
-		gboolean       is_user = FALSE;
+		EmpathyMessage     *message;
+		EmpathyContact     *sender;
+		gchar              *time;
+		EmpathyTime         t;
+		gchar              *sender_id;
+		gchar              *sender_name;
+		gchar              *body;
+		gchar              *is_user_str;
+		gboolean            is_user = FALSE;
+		gchar              *msg_type_str;
+		EmpathyMessageType  msg_type = EMPATHY_MESSAGE_TYPE_NORMAL;
 
 		if (strcmp (node->name, "message") != 0) {
 			continue;
@@ -339,18 +343,23 @@ empathy_log_manager_get_messages_for_date (EmpathyLogManager *manager,
 		sender_id = xmlGetProp (node, "id");
 		sender_name = xmlGetProp (node, "name");
 		is_user_str = xmlGetProp (node, "isuser");
+		msg_type_str = xmlGetProp (node, "type");
 
 		if (is_user_str) {
 			is_user = strcmp (is_user_str, "true") == 0;
 		}
+		if (msg_type_str) {
+			msg_type = empathy_message_type_from_str (msg_type_str);
+		}
 
-		t = gossip_time_parse (time);
+		t = empathy_time_parse (time);
 
-		sender = gossip_contact_new_full (account, sender_id, sender_name);
-		gossip_contact_set_is_user (sender, is_user);
-		message = gossip_message_new (body);
-		gossip_message_set_sender (message, sender);
-		gossip_message_set_timestamp (message, t);
+		sender = empathy_contact_new_full (account, sender_id, sender_name);
+		empathy_contact_set_is_user (sender, is_user);
+		message = empathy_message_new (body);
+		empathy_message_set_sender (message, sender);
+		empathy_message_set_timestamp (message, t);
+		empathy_message_set_type (message, msg_type);
 
 		messages = g_list_append (messages, message);
 
@@ -359,17 +368,39 @@ empathy_log_manager_get_messages_for_date (EmpathyLogManager *manager,
 		xmlFree (sender_id);
 		xmlFree (sender_name);
 		xmlFree (body);
+		xmlFree (is_user_str);
+		xmlFree (msg_type_str);
 	}
 
-	gossip_debug (DEBUG_DOMAIN, "Parsed %d messages", g_list_length (messages));
+	empathy_debug (DEBUG_DOMAIN, "Parsed %d messages", g_list_length (messages));
 
-	g_free (filename);
 	xmlFreeDoc (doc);
 	xmlFreeParserCtxt (ctxt);
 
 	return messages;
 }
 
+GList *
+empathy_log_manager_get_messages_for_date (EmpathyLogManager *manager,
+					   McAccount         *account,
+					   const gchar       *chat_id,
+					   gboolean           chatroom,
+					   const gchar       *date)
+{
+	gchar *filename;
+	GList *messages;
+
+	g_return_val_if_fail (EMPATHY_IS_LOG_MANAGER (manager), NULL);
+	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
+	g_return_val_if_fail (chat_id != NULL, NULL);
+
+	filename = log_manager_get_filename_for_date (manager, account, chat_id, chatroom, date);
+	messages = empathy_log_manager_get_messages_for_file (manager, filename);
+	g_free (filename);
+
+	return messages;
+}
+
 GList *
 empathy_log_manager_get_last_messages (EmpathyLogManager *manager,
 				       McAccount         *account,
@@ -430,7 +461,7 @@ empathy_log_manager_search_new (EmpathyLogManager *manager,
 	text_casefold = g_utf8_casefold (text, -1);
 
 	files = log_manager_get_all_files (manager, NULL);
-	gossip_debug (DEBUG_DOMAIN, "Found %d log files in total",
+	empathy_debug (DEBUG_DOMAIN, "Found %d log files in total",
 		      g_list_length (files));
 
 	for (l = files; l; l = l->next) {
@@ -460,7 +491,7 @@ empathy_log_manager_search_new (EmpathyLogManager *manager,
 
 			if (hit) {
 				hits = g_list_prepend (hits, hit);
-				gossip_debug (DEBUG_DOMAIN, 
+				empathy_debug (DEBUG_DOMAIN, 
 					      "Found text:'%s' in file:'%s' on date:'%s'...",
 					      text, hit->filename, hit->date);
 			}
@@ -479,21 +510,10 @@ empathy_log_manager_search_new (EmpathyLogManager *manager,
 void
 empathy_log_manager_search_free (GList *hits)
 {
-	GList               *l;
-	EmpathyLogSearchHit *hit;
+	GList *l;
 
 	for (l = hits; l; l = l->next) {
-		hit = l->data;
-
-		if (hit->account) {
-			g_object_unref (hit->account);
-		}
-
-		g_free (hit->date);
-		g_free (hit->filename);
-		g_free (hit->chat_id);
-
-		g_slice_free (EmpathyLogSearchHit, hit);
+		log_manager_search_hit_free (l->data);
 	}
 	
 	g_list_free (hits);
@@ -503,11 +523,11 @@ empathy_log_manager_search_free (GList *hits)
 gchar *
 empathy_log_manager_get_date_readable (const gchar *date)
 {
-	GossipTime t;
+	EmpathyTime t;
 
-	t = gossip_time_parse (date);
+	t = empathy_time_parse (date);
 
-	return gossip_time_to_string_local (t, "%a %d %b %Y");
+	return empathy_time_to_string_local (t, "%a %d %b %Y");
 }
 
 static const gchar *
@@ -681,12 +701,12 @@ log_manager_get_filename_for_date (EmpathyLogManager *manager,
 static gchar *
 log_manager_get_timestamp_filename (void)
 {
-	GossipTime  t;
+	EmpathyTime  t;
 	gchar      *time_str;
 	gchar      *filename;
 
-	t = gossip_time_get_current ();
-	time_str = gossip_time_to_string_local (t, LOG_TIME_FORMAT);
+	t = empathy_time_get_current ();
+	time_str = empathy_time_to_string_local (t, LOG_TIME_FORMAT);
 	filename = g_strconcat (time_str, LOG_FILENAME_SUFFIX, NULL);
 
 	g_free (time_str);
@@ -695,14 +715,14 @@ log_manager_get_timestamp_filename (void)
 }
 
 static gchar *
-log_manager_get_timestamp_from_message (GossipMessage *message)
+log_manager_get_timestamp_from_message (EmpathyMessage *message)
 {
-	GossipTime t;
+	EmpathyTime t;
 
-	t = gossip_message_get_timestamp (message);
+	t = empathy_message_get_timestamp (message);
 
 	/* We keep the timestamps in the messages as UTC. */
-	return gossip_time_to_string_utc (t, LOG_TIME_FORMAT_FULL);
+	return empathy_time_to_string_utc (t, LOG_TIME_FORMAT_FULL);
 }
 
 static EmpathyLogSearchHit *
@@ -741,3 +761,16 @@ log_manager_search_hit_new (EmpathyLogManager *manager,
 	return hit;
 }
 
+static void
+log_manager_search_hit_free (EmpathyLogSearchHit *hit)
+{
+	if (hit->account) {
+		g_object_unref (hit->account);
+	}
+
+	g_free (hit->date);
+	g_free (hit->filename);
+	g_free (hit->chat_id);
+
+	g_slice_free (EmpathyLogSearchHit, hit);
+}
